=======
wsipipe
=======


.. image:: https://img.shields.io/pypi/v/wsipipe.svg
        :target: https://pypi.python.org/pypi/wsipipe

.. image:: https://img.shields.io/travis/davemor/wsipipe.svg
        :target: https://travis-ci.com/davemor/wsipipe

.. image:: https://readthedocs.org/projects/wsipipe/badge/?version=latest
        :target: https://wsipipe.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status
        
.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.7060584.svg
        :target: https://doi.org/10.5281/zenodo.7060584



A set of tools for processing pathology whole slide images for deep learning.



* Free software: MIT license
* Documentation: https://wsipipe.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
